@@ -3,7 +3,7 @@ package Module::Install::DSL;
 use strict;
 use vars qw{$VERSION $ISCORE};
 BEGIN {
-	$VERSION = '1.02';
+	$VERSION = '1.03';
 	$ISCORE  = 1;
 	*inc::Module::Install::DSL::VERSION = *VERSION;
 	@inc::Module::Install::DSL::ISA     = __PACKAGE__;
@@ -58,7 +58,8 @@ sub dsl2code {
 	my @lines = grep { /\S/ } split /[\012\015]+/, $dsl;
 
 	# Each line represents one command
-	my @code = ();
+	my @code   = ();
+	my $static = 1;
 	foreach my $line ( @lines ) {
 		# Split the lines into tokens
 		my @tokens = split /\s+/, $line;
@@ -73,6 +74,10 @@ sub dsl2code {
 				# This is the beginning of a suffix
 				push @suffix, $token;
 				push @suffix, @tokens;
+
+				# The conditional means this distribution
+				# can no longer be considered fully static.
+				$static = 0;
 				last;
 			} else {
 				# Convert to a string
@@ -86,6 +91,9 @@ sub dsl2code {
 		push @code, join( ' ', @tokens ) . ";\n";
 	}
 
+	# Is our configuration static?
+	push @code, "static_config;\n" if $static;
+
 	# Join into the complete code block
 	return join( '', @code );
 }
